# Enrichr

This module allows for gene set enrichment analysis using [Enrichr](https://maayanlab.cloud/Enrichr)
as well as other methods to explore gene sets provided within the service.

This tool currently has two submodules.

| Module | Description |
|--------|-------------|
|[`enrichr`](./enrichr/enrichr.md)| Performs a gene-set enrichment analysis |
|[`list`](./enrichr/list.md)| Lists and explores available background libraries |
